# About

This project is a GUI wrapper for pyCLAMs (https://github.com/zhangys11/pyCLAMs).  
The original version is developed in ASP.Net MVC (http://qsi.zhangys.org.cn/research/cla/). This project has rewritten it using Flask.    
Developed by Dr. Zhang (oo@zju.edu.cn).   

# Install

pip install wCLAMs


# Run directly from source

1. git clone https://github.com/zhangys11/wCLAMs.git
2. cd wCLAMs/app/
3. python wCLAMs.py
4. Go to http://0.0.0.0:5005/

# ScreenCut

<img src="wCLAMs.jpg">